powered by
Data on the annual numbers of lynx trapped in the Mackenzie River district of northwest Canada from 1821--1934.
ex1515
A data frame with 114 observations on the following 3 variables.
year
number of lynx trapped
number of sunspots
Elston, C. and Nicholson, M. (1942). The Ten Year Cycle in Numbers of the Lynx in Canada, Journal of Animal Ecology 11(2): 215--244.
# NOT RUN { str(ex1515) # }
Run the code above in your browser using DataLab